@@ -19,7 +19,7 @@ def delete_repo(repo):
 
 
 def get_ref(repo, refname):
-    return _github(root="repos", path=f"{repo}/git/refs/{refname}", method="GET")
+    return _github(root="repos", path=f"{repo}/git/refs/heads/{refname}", method="GET")
 
 
 def create_ref(repo, refname, sha):
@@ -51,7 +51,7 @@ def update_contents(repo, filename, content, branch, message):
         root="repos",
         path=f"{repo}/contents/{filename}",
         method="PUT",
-        body={"message": message, "branch": branch, "content": content,},
+        body={"message": message, "branch": branch, "content": content},
     )
 
 
@@ -60,5 +60,5 @@ def delete_contents(repo, filename, branch, message):
         root="repos",
         path=f"{repo}/contents/{filename}",
         method="DELETE",
-        body={"message": message, "branch": branch,},
+        body={"message": message, "branch": branch},
     )
